@@ -1,5 +1,6 @@
-# TODO: support additional apache formats (http://ossec-docs.readthedocs.org/en/latest/log_samples/apache/apache.html)  # NOQA
-# TODO: maybe consolidate Json and Custom formatters to the same class, to let other custom formatters use them both for each type implemented  # NOQA
+# TODO: (FEAT) support additional apache formats (http://ossec-docs.readthedocs.org/en/latest/log_samples/apache/apache.html)  # NOQA
+# TODO: (FEAT) maybe consolidate Json and Custom formatters to the same class, to let other custom formatters use them both for each type implemented  # NOQA
+# TODO: (FEAT) implement Tomcat Formatter
 
 import random
 from abc import abstractmethod, ABCMeta
@@ -12,7 +13,7 @@ import uuid
 DEFAULT_CUSTOM_FORMAT = [
     'current_date_time', ' ', 'uuid', ' ', 'level', ': ',
     'module', ' - ', 'free_email'
-],
+]
 DEFAULT_CUSTOM_DATA = {
     'current_date_time': '$RAND',
     'uuid': [str(uuid.uuid1()) for i in xrange(100)],
@@ -99,7 +100,7 @@ class CustomFormatter(BaseFormatter):
      ...
     """
     def __init__(self, config):
-        self.format = config.get('format', DEFAULT_CUSTOM_FORMAT)[0]
+        self.format = config.get('format', DEFAULT_CUSTOM_FORMAT)
         self.data = config.get('data', DEFAULT_CUSTOM_DATA)
 
     def generate_data(self):
@@ -151,6 +152,7 @@ class JsonFormatter(BaseFormatter):
         self.data = config.get('data', DEFAULT_CUSTOM_DATA)
 
     def generate_data(self):
+        # TODO: (FEAT) support randomizing data fields in Json formatter
         log = {}
         for field, data in self.data.items():
             if data == '$RAND':
